Skip to contents

A wrapper function that combines data validation and preprocessing steps. See validate_melatonin_profile for more details.

Usage

preprocess_profile(
  profile,
  threshold = 2.3,
  min_increase_points = 3,
  min_points = 3
)

Arguments

profile

A numeric vector representing the profile data points.

threshold

Numeric value for the minimum rise threshold, default is 2.3.

min_increase_points

Integer specifying the minimum number of consecutive points above the threshold to establish a rise, default is 3.

min_points

Integer specifying the minimum number of data points required for the profile, default is 3.