Compute Constraint Violations for Parallelogram Fit
Source:R/optimize_parallelogram.R
constraints.RdGiven a set of parameters, this function computes constraint violations, ensuring that all points remain inside the parallelogram.
R/optimize_parallelogram.R
constraints.RdGiven a set of parameters, this function computes constraint violations, ensuring that all points remain inside the parallelogram.